@@ -21,6 +21,7 @@ class URLs:
         self.doAllNew = "do_all_new"
         self.doAllAlter = "do_all_alter"
         self.doAllSummer = "do_all_summer"
+        self.doAllWinter = "do_all_winter"
 
     def base_url(self):
         return self.base_url
@@ -64,6 +65,10 @@ class URLs:
     def doAllSummer_url(self):
         url = self.base_url % self.doAllSummer
         return url
+
+    def doAllWinter_url(self):
+        url = self.base_url % self.doAllWinter
+        return url
     
 
 class Api():
@@ -164,4 +169,8 @@ class Api():
 
     def do_All_summer(self, session_id, content):
         """Returns all. Custom format 3"""
-        return self.__get_data(session_id, self.url.doAllSummer_url(), content)
\ No newline at end of file
+        return self.__get_data(session_id, self.url.doAllSummer_url(), content)
+
+    def do_All_winter(self, session_id, content):
+        """Returns all. Custom format 4"""
+        return self.__get_data(session_id, self.url.doAllWinter_url(), content)
\ No newline at end of file
